==> nvidia-installer-1.0.1.tar.gz: nvidia-installer-1.0.1/precompiled.h <==
/*
 * nvidia-installer: A tool for installing NVIDIA software packages on
 * Unix and Linux systems.
 *
 * Copyright (C) 2003 NVIDIA Corporation
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the:
 *
 *      Free Software Foundation, Inc.
 *      59 Temple Place - Suite 330
 *      Boston, MA 02111-1307, USA
 *
 *
 * precompiled.h
 */

#ifndef __NVIDIA_INSTALLER_PRECOMPILED_H__
#define __NVIDIA_INSTALLER_PRECOMPILED_H__

#define OUTPUT_FILENAME "nv-linux.o"

typedef struct {
    
    uint32 crc;
    uint32 major;
    uint32 minor;
    uint32 patch;
    char *proc_version_string;
    char *description;

} PrecompiledInfo;


char *read_proc_version(Options *op);

PrecompiledInfo *precompiled_unpack(Options *op,
                                    const char *filename,
                                    const char *output_filename,
                                    const char *real_proc_version_string);


#endif /* __NVIDIA_INSTALLER_PRECOMPILED_H__ */

==> nvidia-installer-1.0.7-07-29-05.tar.gz: nvidia-installer-1.0.7/precompiled.h <==
/*
 * nvidia-installer: A tool for installing NVIDIA software packages on
 * Unix and Linux systems.
 *
 * Copyright (C) 2003 NVIDIA Corporation
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the:
 *
 *      Free Software Foundation, Inc.
 *      59 Temple Place - Suite 330
 *      Boston, MA 02111-1307, USA
 *
 *
 * precompiled.h
 */

#ifndef __NVIDIA_INSTALLER_PRECOMPILED_H__
#define __NVIDIA_INSTALLER_PRECOMPILED_H__

#define OUTPUT_FILENAME "nv-linux.o"

typedef struct {
    
    uint32 crc;
    uint32 major;
    uint32 minor;
    uint32 patch;
    char *proc_version_string;
    char *description;

} PrecompiledInfo;


char *read_proc_version(Options *op);

PrecompiledInfo *precompiled_unpack(Options *op,
                                    const char *filename,
                                    const char *output_filename,
                                    const char *real_proc_version_string,
                                    const int package_major,
                                    const int package_minor,
                                    const int package_patch);


#endif /* __NVIDIA_INSTALLER_PRECOMPILED_H__ */
